Package: dMod
Type: Package
Title: Dynamic Modeling and Parameter Estimation in ODE Models
Version: 1.0.2
Date: 2021-01-25
Author: Daniel Kaschek
Maintainer: Daniel Kaschek <daniel.kaschek@gmail.com>
Description: The framework provides functions to generate ODEs of reaction
    networks, parameter transformations, observation functions, residual functions,
    etc. The framework follows the paradigm that derivative information should be
    used for optimization whenever possible. Therefore, all major functions produce
    and can handle expressions for symbolic derivatives. The methods used in dMod
    were published in Kaschek et al, 2019, <doi:10.18637/jss.v088.i10>.
License: GPL (>= 2)
Depends: cOde (>= 1.0),
Imports: deSolve, rootSolve, ggplot2, parallel, stringr, plyr, dplyr,
        foreach, doParallel
Suggests: MASS, reticulate, pander, knitr, rmarkdown
RoxygenNote: 7.0.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2021-01-26 21:30:28 UTC; kaschek
Repository: CRAN
Date/Publication: 2021-01-27 00:30:13 UTC
Built: R 4.6.0; ; 2026-04-29 01:54:01 UTC; unix
