# Generated by roxygen2: do not edit by hand

S3method("*",fn)
S3method("+",datalist)
S3method("+",fn)
S3method("+",objfn)
S3method("+",objlist)
S3method("[",datalist)
S3method("[",eqnvec)
S3method("[",parframe)
S3method("[",parvec)
S3method("[",prdlist)
S3method("controls<-",fn)
S3method("controls<-",objfn)
S3method("modelname<-",fn)
S3method("modelname<-",objfn)
S3method("names<-",datalist)
S3method(addEvent,"NULL")
S3method(addEvent,eventlist)
S3method(as.data.frame,datalist)
S3method(as.data.frame,eqnlist)
S3method(as.data.frame,prdlist)
S3method(as.datalist,data.frame)
S3method(as.datalist,list)
S3method(as.eqnlist,data.frame)
S3method(as.eqnvec,character)
S3method(as.eqnvec,eqnlist)
S3method(as.eventlist,data.frame)
S3method(as.eventlist,list)
S3method(as.parframe,parlist)
S3method(as.parvec,numeric)
S3method(as.parvec,parframe)
S3method(as.prdlist,list)
S3method(c,datalist)
S3method(c,eqnlist)
S3method(c,eqnvec)
S3method(c,parlist)
S3method(c,parvec)
S3method(c,prdlist)
S3method(compare,character)
S3method(compare,data.frame)
S3method(compare,eqnvec)
S3method(compare,list)
S3method(confint,parframe)
S3method(controls,fn)
S3method(controls,objfn)
S3method(covariates,data.frame)
S3method(covariates,datalist)
S3method(format,eqnvec)
S3method(getConditions,fn)
S3method(getConditions,list)
S3method(getDerivs,list)
S3method(getDerivs,objlist)
S3method(getDerivs,parvec)
S3method(getDerivs,prdframe)
S3method(getDerivs,prdlist)
S3method(getEquations,fn)
S3method(getEquations,odemodel)
S3method(getEquations,prdfn)
S3method(getParameters,eqnlist)
S3method(getParameters,eventlist)
S3method(getParameters,fn)
S3method(getParameters,odemodel)
S3method(getParameters,parvec)
S3method(getParameters,prdframe)
S3method(getParameters,prdlist)
S3method(mname,"NULL")
S3method(mname,character)
S3method(mname,fn)
S3method(mname,objfn)
S3method(plot,datalist)
S3method(plot,parlist)
S3method(plot,prdframe)
S3method(plot,prdlist)
S3method(plotCombined,prdlist)
S3method(plotData,data.frame)
S3method(plotData,datalist)
S3method(plotPars,parframe)
S3method(plotPrediction,prdlist)
S3method(plotProfile,list)
S3method(plotProfile,parframe)
S3method(plotValues,parframe)
S3method(predict,prdfn)
S3method(print,datalist)
S3method(print,eqnlist)
S3method(print,eqnvec)
S3method(print,objfn)
S3method(print,obsfn)
S3method(print,odemodel)
S3method(print,parfn)
S3method(print,parvec)
S3method(print,prdfn)
S3method(print,prdframe)
S3method(print,prdlist)
S3method(subset,datalist)
S3method(subset,eqnlist)
S3method(subset,parframe)
S3method(summary,eqnvec)
S3method(summary,obsfn)
S3method(summary,parfn)
S3method(summary,parlist)
S3method(summary,prdfn)
S3method(unique,parframe)
S3method(wide2long,data.frame)
S3method(wide2long,list)
S3method(wide2long,matrix)
export("%.*%")
export("+.objlist")
export("controls<-")
export("modelname<-")
export(Id)
export(P)
export(Pexpl)
export(Pimpl)
export(Xd)
export(Xf)
export(Xs)
export(Xt)
export(Y)
export(addEvent)
export(addReaction)
export(as.datalist)
export(as.eqnlist)
export(as.eqnvec)
export(as.eventlist)
export(as.objlist)
export(as.parframe)
export(as.parlist)
export(as.parvec)
export(as.prdlist)
export(attrs)
export(blockdiagSymb)
export(branch)
export(c.parlist)
export(combine)
export(compare)
export(compile)
export(conservedQuantities)
export(constraintL2)
export(controls)
export(coordTransform)
export(covariates)
export(datalist)
export(datapointL2)
export(define)
export(dot)
export(eqnlist)
export(eqnvec)
export(eventlist)
export(fitErrorModel)
export(forcingsSymb)
export(format.eqnvec)
export(funC0)
export(getConditions)
export(getDerivs)
export(getEquations)
export(getFluxes)
export(getLocalDLLs)
export(getObservables)
export(getParameters)
export(getReactions)
export(ggopen)
export(insert)
export(is.datalist)
export(is.eqnlist)
export(is.eqnvec)
export(is.parframe)
export(lbind)
export(load.parlist)
export(loadDLL)
export(long2wide)
export(lsdMod)
export(match.fnargs)
export(mname)
export(modelname)
export(msParframe)
export(mstrust)
export(nll)
export(normL2)
export(nullZ)
export(objframe)
export(objlist)
export(obsfn)
export(odemodel)
export(parfn)
export(parframe)
export(parlist)
export(parvec)
export(plotCombined)
export(plotData)
export(plotFluxes)
export(plotPars)
export(plotPaths)
export(plotPrediction)
export(plotProfile)
export(plotResiduals)
export(plotValues)
export(prdfn)
export(prdframe)
export(prdlist)
export(print0)
export(priorL2)
export(profile)
export(progressBar)
export(reduceReplicates)
export(repar)
export(res)
export(resolveRecurrence)
export(rref)
export(scale_color_dMod)
export(scale_fill_dMod)
export(steadyStates)
export(submatrix)
export(subset.eqnlist)
export(symmetryDetection)
export(theme_dMod)
export(trust)
export(trustL1)
export(wide2long)
export(wide2long.data.frame)
export(wide2long.list)
export(wide2long.matrix)
export(write.eqnlist)
export(wrss)
import(cOde)
import(deSolve)
import(ggplot2)
import(parallel)
import(rootSolve)
import(stringr)
importFrom(dplyr,filter)
importFrom(dplyr,left_join)
importFrom(graphics,par)
importFrom(plyr,ddply)
importFrom(plyr,summarise)
importFrom(stats,D)
importFrom(stats,approx)
importFrom(stats,as.formula)
importFrom(stats,dnorm)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,qchisq)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,time)
importFrom(stats,uniroot)
importFrom(utils,file.edit)
importFrom(utils,getParseData)
importFrom(utils,install.packages)
importFrom(utils,installed.packages)
importFrom(utils,read.csv)
importFrom(utils,str)
importFrom(utils,tail)
importFrom(utils,write.csv)
importFrom(utils,write.table)
